import { App } from 'vue';
import { SearchOptions as SearchOptions$1 } from 'slimsearch';

type Word = [tag: string, content: string] | string;
declare const enum ResultType {
    title = "t",
    heading = "h",
    text = "p",
    custom = "c"
}
declare const enum ResultField {
    type = "t",
    key = "k",
    anchor = "a",
    header = "h",
    index = "i",
    display = "d"
}
interface TitleMatchedItem {
    [ResultField.type]: ResultType.title;
    [ResultField.key]: string;
    [ResultField.display]: Word[][];
}
interface HeadingMatchedItem {
    [ResultField.type]: ResultType.heading;
    [ResultField.key]: string;
    [ResultField.anchor]: string;
    [ResultField.display]: Word[][];
}
interface ContentMatchedItem {
    [ResultField.type]: ResultType.text;
    [ResultField.key]: string;
    [ResultField.header]?: string;
    [ResultField.anchor]?: string;
    [ResultField.display]: Word[][];
}
interface CustomMatchedItem {
    [ResultField.type]: ResultType.custom;
    [ResultField.key]: string;
    [ResultField.index]: string;
    [ResultField.display]: Word[][];
}
type MatchedItem = TitleMatchedItem | HeadingMatchedItem | ContentMatchedItem | CustomMatchedItem;
interface SearchResult {
    title: string;
    contents: MatchedItem[];
}

type SearchOptions = Omit<SearchOptions$1, "fields">;

declare const defineSearchConfig: (options: SearchOptions) => void;
declare const useSearchOptions: () => SearchOptions;
declare const injectSearchConfig: (app: App) => void;

interface SearchWorker {
    search: (query: string, locale: string, searchOptions?: SearchOptions) => Promise<SearchResult[]>;
    terminate: () => void;
}
declare const createSearchWorker: () => SearchWorker;

export { SearchWorker, createSearchWorker, defineSearchConfig, injectSearchConfig, useSearchOptions };
